/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file fontmenu.h
 *
 * @type helper
 *
 * @description
 *
 * The fontmenu helper is used to create a menu giving a list of fonts.
 */

#ifndef __rov_fontmenu
#define __rov_fontmenu


#ifdef __cplusplus
extern "C"
{
#endif

#ifndef __rov_menu
#include "menu.h"
#endif

/**
 * Definition of a fontmenu handler.
 * @param font_name the name of the font chosen.
 */
typedef void (* fontmenu_handlep)(char *font_name);

/**
 * Create a font menu.
 * @param handler the font menu handler.
 * @return the generated menu.
 * @note You can only create one font_menu per application.
 * @see menu.h
 * @see fontmenu_handlep()
 */
menu fontmenu_create(fontmenu_handlep handler);

/**
 * Tick a font name.
 * @param font_name the name to tick (or NULL to not tick any).
 */
void fontmenu_tickfont(char *font_name);


#ifdef __cplusplus
}
#endif

#endif
